![gh-action badge](https://github.com/SynBioDex/pySBOL3/workflows/Python%20package/badge.svg)
![readthedocs badge](https://readthedocs.org/projects/pysbol3/badge/)
# pySBOL3

This is a [Python](https://www.python.org/) implementation of the
[SBOL 3 specification](https://sbolstandard.org/data-model-specification/).

This library is at a pre-alpha stage. Intrepid pre-alpha users are
welcome. Please file
[issues](https://github.com/SynBioDex/pySBOL3/issues) about bugs and
missing features.

## Installation

Use pip to install the library:

```
pip install sbol3
```

## Documentation

[Full documentation for pySBOL3 is available at read-the-docs](https://pysbol3.readthedocs.io).

## Development

Please
[fork the GitHub repository](https://guides.github.com/activities/forking/),
and follow
[GitHub flow](https://guides.github.com/introduction/flow/)
for development.

## Acknowledgements

Development of this library has been supported by the 
[DARPA Synergistic Discovery and Design (SD2)](https://www.darpa.mil/program/synergistic-discovery-and-design)
program and [Raytheon BBN Technologies](http://bbn.com/).
